@@ -4,10 +4,10 @@ import civilianM as cm
 #Author : AC97
 #Project name : civilianM
 #Class : AUX/ For wang-jin-hu Only
-#Now version: V1.80.97
+#Now version: V1.97.97
 #Contact EMail: ehcemc@163.com
 #NO COPYING!
-class i():
+class test():
     def __init__(self):
         mx='不可以昧着良心说话！'
         xt='不可以瞎填！'
@@ -18,11 +18,12 @@ class i():
                 print("这才对")
                 return None
             elif b == False:
-                raise FutureWarning(mx)
+                raise ConscienceError(mx)
             elif b == None:
                 raise SyntaxError(xt)
         elif a == True:
-            raise SyntaxWarning(mx)
+            raise ConscienceError(mx)
         elif a == None:
             raise SyntaxError(xt)
 
+
